@@ -22,14 +22,13 @@ from . import acting
 from .consoling import getConsole
 console = getConsole()
 
-from .aiding import NonStringIterable, just, nameToPath
+from .aiding import nonStringIterable, just, nameToPath
 
 def deedify(name, base=None, registry=None, inits=None, ioinits=None, parms=None,
             parametric=None):
     """ Parametrized decorator function that converts the decorated function
-        into an Actor sub class with .action method and with class name that
-        is the reverse camel case of name and registers the
-        new subclass in the registry under name.
+        into an Actor sub class with .action method and with class name name
+        and registers the new subclass in the registry under name.
         If base is not provided then use Deed
 
         The parameters  registry, parametric, inits, ioinits, and parms if provided,
@@ -156,15 +155,15 @@ class DeedLapse(Deed):
         print("Deed %s stamp = %s lapse = %s" % (self.name, self.stamp, self.lapse))
 
     def resolve(self, **kwa):
-        """ Create enact with RestarterActor to restart this Actor """
+        """ Create enact with restart SideAct to restart this Actor """
         parms = super(DeedLapse, self).resolve( **kwa)
 
-        kind = 'Restarter'
-        restartAct = acting.Act( actor=kind,
-                                 registrar=acting.Actor,
-                                 parms=odict(act=self.act),
-                                 inits=odict(name=kind), )
-
+        restartActParms = {}
+        restartAct = acting.SideAct(   actor=self,
+                                parms=restartActParms,
+                                action='restart',
+                                human=self.act.human,
+                                count=self.act.count)
         # need to insert restartAct before self.act so restartAct runs first
         found = False
         for i, enact in enumerate(self.act.frame.enacts):
@@ -175,9 +174,7 @@ class DeedLapse(Deed):
         if not found:
             self.act.frame.addEnact(restartAct)
 
+        console.profuse("{0}Added enact {1} SideAct for {2} with {3} in {4}\n".format(
+                INDENT_ADD, 'restart', self.name, restartAct.parms, self.act.frame.name))
         restartAct.resolve()
-
-        console.profuse("     Added {0} {1} for {2} in {3}\n".format(
-            'enact', kind, self.name, self.act.frame.name ))
-
         return parms
